;; 
;; 1998-2008 (p) A. Tenbusch
;; 
;; 
;; pie-mode
;; pie-xml-mode
;; configuration imenu
;; 
;; emacs -q -l ~/develop/cxproc/contrib/pie/elisp/pie.el /tmp/test.txt &


;; external programs: xsltproc, cxproc, ...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie global settings
;;;

(unless (getenv "PATHXSL")
  (setenv "PATHXSL" (concat (file-name-directory (buffer-file-name)) "../../.."))
  )

(set-language-environment 'utf-8)

(if window-system
    (progn
      ;;(global-font-lock-mode t)
      (require 'imenu)
      (require 'speedbar)
      (speedbar-add-supported-extension ".txt")
      (speedbar-add-supported-extension ".pie")
      (require 'goto-addr)
      )
  )

(require 'psgml)

(require 'time-stamp)
(add-hook 'write-file-hooks 'time-stamp)
(setq time-stamp-start "Speicherung[ \t]+\\\\?[\"<]+")
(setq time-stamp-format "%f %:d.%:m.%:y %02H:%02M:%02S %u")
;;

;(speedbar-frame-mode 1)


;  (local-set-key    [print] 'txt2x-ps-print)

;  (local-set-key    [S-f4]  'txt2x-wcount-on-region)
;  (local-set-key      [f4]  'txt2x-wcount-paragraph)

;  (local-set-key      [f6]  'txt2x-search-current-word)
;  (local-set-key      [C-f6]  'txt2x-search-in-buffer-file)
;  (local-set-key      [S-f6]  'txt2x-search)

;  (local-set-key    [f8] 'hide-body)
;  (local-set-key    [f9] 'show-subtree)


;; (setq auto-mode-alist
;;       (append
;;        (list
;; 	'("\\.cxp" . xml-mode)
;; 	)
;;        auto-mode-alist))


(define-minor-mode pie-minor-mode
  "This is the global minor mode for PIE."
  :lighter " PIE" :global nil

  ;;     (define-key-after
  ;;       'mode-line-mode-menu
  ;;       (pie-plain-minor-mode menu-item "PIE"  :button pie-plain-minor-mode
  ;; 		      (:toggle bound-and-true-p outline-minor-mode))  
  ;;       )

  (if (string= (file-name-extension (buffer-file-name)) "txt")
      (pie-plain-minor-mode)
    (if (string= (file-name-extension (buffer-file-name)) "pie")
	(pie-xml-minor-mode)
      (message "Unknown extension")
      )
    )
  )

(add-hook 'text-mode-hook 'pie-minor-mode)
(add-hook 'text-mode-hook 'outline-minor-mode)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie plain
;;;

(defvar pie-plain-imenu-generic-expression
  '(
    ("Sections" "^[*%]+.*" 0)
    ("Remarks"  "^[;]+.*"  0)
    ("Markups"  "^[#]+.*"   0)
    ("Figures"  "^Abb\\.\\s-+\\([-A-Za-z0-9_.]+\\)\\s-*:" 1))
  "Imenu generic expression for PIE mode.  See `imenu-generic-expression'.")


(defun pie-plain-minor-mode ()
  "This is the plain text mode for PIE."

  (interactive)
  ;;
  (auto-fill-mode 1)
  ;(setq fill-column 70)
  ;;
  (line-number-mode 1)
  (column-number-mode 1)
  ;;
;  (outline-minor-mode 1)
  ;;
  ;; fügt deutsche Anführungszeichen ein
  (local-set-key "\e1"
		 (lambda () ""
		   (interactive)
		   (insert "><")
		   (backward-char 1)))
  ;; fügt deutsche doppelte Anführungszeichen ein
  (local-set-key "\e2"
		 (lambda () ""
		   (interactive)
		   (insert ">><<")
		   (backward-char 2)))
  ;;
  (if window-system
      (progn
	;; font-lock
	(font-lock-mode t)
	(setq font-lock-keywords '(     ; Reihenfolge ist wichtig
					; section
				   ("^ *[\*%]+.*$" . font-lock-function-name-face)
					; CPP-Anweisungen
				   ("^[ ;]*#+.*$" . font-lock-keyword-face)
					; Kommentare
				   ("^ *;+.*$" . font-lock-comment-face)
					; cite
					;("\\[[a-zA-Z0-9\,\-]*\\]" . font-lock-variable-name-face)
					; Todo
				   ("^\{.+\} " . font-lock-reference-face)
					; Abb
					;("[Aa][Bb][Bb][\\.:]" . font-lock-reference-face)
					; Tab
					;("[Tt][Aa][Bb][\\.:]" . font-lock-reference-face)
					; Aufzaehlungen
				   ("^ *[\-\+]+" . font-lock-variable-name-face)
					; quotes
				   ("[><]+" . font-lock-variable-name-face)
					; ldots
;				   ("\\.\\.\\." . font-lock-variable-name-face)
					; i.d.R.
					;("i\\. *d\\. *R\\." . font-lock-variable-name-face)
					; z.B.
					;("z\\. *B\\." . font-lock-variable-name-face)
					; d.h.
					;("d\\. *h\\." . font-lock-variable-name-face)
				   ))
	(font-lock-fontify-buffer)
	;; BUG: font-lock isnt active first time
	;;
	(goto-address)
	;;  (goto-address-fontify)
	;;
	;; imenu
	;; sonst entsprechend imenu-example--* anpassen
	(set (make-local-variable 'imenu-generic-expression)
	     pie-plain-imenu-generic-expression)
	(setq
	 imenu-case-fold-search nil
	 speedbar-tag-hierarchy-method '(speedbar-trim-words-tag-hierarchy)
	 )
	)
    (progn				; Text-Modus
      )
    )
  (set (make-local-variable 'pie-mode-enabled) t)
  (message "'pie-plain-minor-mode' loaded")
;  (run-mode-hooks 'text-mode-hook)
  )
;; (pie-plain-minor-mode)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie XML
;;;

; http://www.snee.com/bob/sgmlfree/emcspsgm.html#colors

(make-face 'sgml-comment-face)
(make-face 'sgml-start-tag-face)
(make-face 'sgml-end-tag-face)
(make-face 'sgml-entity-face)
(make-face 'sgml-doctype-face)

(set-face-foreground 'sgml-comment-face "FireBrick")
(set-face-foreground 'sgml-start-tag-face "light slate gray")
(set-face-foreground 'sgml-end-tag-face "light slate gray")
(set-face-background 'sgml-entity-face "SlateBlue")
(set-face-foreground 'sgml-entity-face "Red")
(set-face-foreground 'sgml-doctype-face "FireBrick")

(setq sgml-set-face t)  ; without this, all SGML text is in same color

(setq sgml-markup-faces
      '(
	(comment   . sgml-comment-face)
	(start-tag . sgml-start-tag-face)
	(end-tag   . sgml-end-tag-face)
	(doctype   . sgml-doctype-face)
	;(entity    . sgml-entity-face)
	))

(defun pie-xml-minor-mode ()
  ""
  (interactive)

;  (sgml-parse-prolog)

; (sgml-doctype-insert  ) sgml-default-dtd-file sgml-custom-dtd sgml-system-path sgml-load-dtd sgml-need-dtd

  ;(require 'iso-sgml)
  ;;
  (if window-system
      (progn
	;; font-lock
	(font-lock-mode t)
	;;
	(goto-address)
	;;  (goto-address-fontify)
	;;
	;; imenu
	;; sonst entsprechend imenu-example--* anpassen
;	(set (make-local-variable 'imenu-generic-expression)
;	     pie-imenu-generic-expression)
	(setq
	 imenu-case-fold-search nil
	 speedbar-tag-hierarchy-method '(speedbar-trim-words-tag-hierarchy)
	 )
	)
    (progn				; Text-Modus
      )
    )

;  (setq sgml-namecase-general nil)
  (setq sgml-set-face t)
  ;(setq sgml-markup-faces '())
  ;;
  (auto-fill-mode -1)
  (setq fill-column 70)
  ;;
  (line-number-mode 1)
  (column-number-mode 1)
  ;;
  ;; fügt deutsche Anführungszeichen ein
  (local-set-key "\e1"
		 (lambda () ""
		   (interactive)
		   (insert "&quot;&quot;")
		   (backward-char 6)))
  ;; fügt deutsche doppelte Anführungszeichen ein
  (local-set-key "\e2"
		 (lambda () ""
		   (interactive)
		   (insert "&quot;&quot;")
		   (backward-char 6)))

  ;; xmllint

  (local-set-key [S-f3]  (lambda ()
			   ""
			   (interactive)
			   
			   (setq
			    buffer-name-xml (buffer-file-name)
					;buffer-xml (get-buffer buffer-name-xml)
			    buffer-xml (get-buffer (buffer-name))
			    buffer-out (get-buffer-create "xmllint-out")
			    buffer-err (get-buffer-create "xmllint-err")
			    )
			   (shell-command (concat "xmllint --valid --dtdvalid ../../pkg2m.dtd " buffer-name-xml) buffer-out buffer-err)
			   (ediff-buffers buffer-xml buffer-out)
			   )
		 )

  (if window-system
      (progn
	(local-set-key [mouse-3]  'sgml-right-menu)
	(local-set-key    [f7] 'browse-url-of-buffer)

;	(pie-ecb-tree)
;; 	;; imenu
;; 	;; sonst entsprechend imenu-example--* anpassen
;; 	(setq 
;; 	 imenu-case-fold-search nil
;; 	 imenu-generic-expression 
;; 	 '(;;
;; 	   ;("Gliederung" "^[*%]+.*" 0)
;; 	   ;(nil "^[*%]+.*" 0)
;; 	   ;("Subnets" "^ *\<SUBNET ID\=.*" 0)
;; 	   (nil "^ *\<SUBNET ID\=.*" 0)
;; 	   ;("Stellen" "^ *\<STELLE ID\=.*" 0)
;; 	   ;("Transitionen" "^ *\<TRANSITION ID\=.*" 0)
;; 	   ;("_3_" "^--- .*"  0)
;; 	   ;("_2_" "^-- .*"  0)
;; 	   ;("_1_" "^- .*"  0)
;; 	   ;("Kommentare" "^[;]+.*"  0)
;; 	   ;("CPP"        "^[#].*"   0)
;; ;	   ("Abb./Tab."  "^[TA][ab]b\\.\\s-+\\([-A-Za-z0-9_.]+\\)\\s-*:" 1)
;; 	   ;("Abb./Tab."  "^[TA][ab]b\\.\\s-+\\([-A-Za-z0-9_.]+\\s-*:.*$\\)" 1)
;; ;	   ("Zitate"     "^.*\\(\\[[a-z0-9,]+\\]\\)" 1)
;; 	   ;("Zitate"     "^.*\\[[a-z0-9\,\-]+\\].*" 0)
;; 	   ;("Termine"     "^.*\\[[a-z0-9\,\-]+\\]*.*" 0)
;; 	   ;("Referenzen" "^.*\\s-+\\(s\\.\\s-+.*\\)" 1)
;; 	   )
;; 					;speedbar-sort-tags t
;; 	 ;speedbar-tag-hierarchy-method '(simple-group)
;; 	 speedbar-tag-hierarchy-method '(speedbar-trim-words-tag-hierarchy)
;; 	 )
	)
    (progn				; Text-Modus
      )
    )

;;  (end-of-buffer)
;;  (beginning-of-buffer)

;  (run-mode-hooks 'pie-xml-minor-mode-hook)
  (set (make-local-variable 'pie-mode-enabled) t)
  (message "'pie-xml-minor-mode' loaded")
  )


(defun pie-xml-insert-task ()
  "insert a task element"
  (interactive)
  ;;
  (setq pie-position (point))
  (setq pie-task-date-str
	(read-from-minibuffer "date="))
  (setq pie-task-effort-str
	(read-from-minibuffer "effort="))
  (setq pie-task-h-str
	(read-from-minibuffer "h: "))
  ;;
  (insert (concat "<task"
		  (if (> (length pie-task-date-str) 0)
		      (concat " date=\"" pie-task-date-str "\"")
		    )
		  (if (> (length pie-task-effort-str) 0)
		      (concat " effort=\"" pie-task-effort-str "\"")
		    )
		  ">\n"
		  "  <h>" pie-task-h-str "</h>\n"
		  "  <contact idref=\"\"/>\n"
		  "</task>\n")
	  )
  (indent-region pie-position (point) nil)
  (re-search-backward "idref=\\\"" nil t)
  (goto-char (match-end 0))
  )


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie transform
;;;

(defvar pie-filename-pie
  (concat (getenv "HOME") "/tmp/emacs.pie")
  "")

(defvar pie-cxproc-command
  (concat "cxproc Validate.xsl > " pie-filename-pie)
  "")


(defun pie-plain-to-xml-buffer (&optional buffer)
  "ruft pie auf um den Buffer von pie- in PIE-Syntax zu bringen."

  (interactive)

  (setq pie-cxproc-command
	(read-from-minibuffer "Command: " pie-cxproc-command))
  (shell-command-on-region (point-min) (point-max) pie-cxproc-command)
  (find-file pie-filename-pie)
  )
;; (pie-plain-to-xml-buffer)


(defun pie-plain-to-xml-clipboard ()
  "ruft pie auf um den Clipboard von pie- in PIE-Syntax zu bringen."

  (interactive)

  (switch-to-buffer (get-buffer-create "clip.txt"))
  (insert (current-kill 0))
  (pie-plain-to-xml-buffer)
  )
;; (pie-plain-to-xml-clipboard)


(defun pie-utf8-to-iso8859-1 ()
  "converts single UTF-8 chars to iso8859-1"

  (interactive)
  (beginning-of-buffer)
  (query-replace "\xc3\xbc" "ü")
  (beginning-of-buffer)
  (query-replace "\xc3\xb6" "ö")
  (beginning-of-buffer)
  (query-replace "\xc3\xa4" "ä")
  )
;; (pie-utf8-to-iso8859-1)


;; (defun pie-parify-buffer ()
;;   "dd"

;;   (interactive)

;;   ;; 
;;   (beginning-of-buffer)
;;   (while (re-search-forward "^\"\t" nil t)
;;     (replace-match "- " nil nil))
;;   ;; 
;;   (beginning-of-buffer)
;;   (while (re-search-forward "^o\t" nil t)
;;     (replace-match "-- " nil nil))
;;   ;; 
;;   (beginning-of-buffer)
;;   (while (re-search-forward "^[0-9]+\\.\t" nil t)
;;     (replace-match "+ " nil nil))
;;   ;; 
;;   (beginning-of-buffer)
;;   (while (search-forward-regexp "\n" nil t)
;;     (insert "\n")
;;     (forward-char 1)
;;     )

;;   ;(beginning-of-buffer)
;;   (pie-piefy-buffer)
;;   )
;; ;; (pie-parify-buffer)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie keywords

(defun pie-extract-keys (file-name-all)
  "returns a list of filtered keywords from a text file."

  (let 
      ((list-of-keys "")
       (case-fold-search nil))

    (find-file file-name-all)
    ;(font-lock-mode -1)
    (setq list-of-words (split-string (buffer-string)))
    (kill-this-buffer)

    (while list-of-words
      (if (and
	   (not (string-match (car list-of-words) list-of-keys))
	   (string-match "^[A-Z]" (car list-of-words))
	   )
	  (setq list-of-keys (concat list-of-keys " " (car list-of-words)))
	)
      (setq list-of-words (cdr list-of-words))
      )
					;(setq case-fold-search case-fold-search-saved)
    list-of-keys
    )
  )
;; (pie-extract-keys "/tmp/e.el")
;; (pie-extract-keys "/tmp/e")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie search

(defun pie-search-overlay (event)
  ""

  (interactive "e")

  (save-excursion
    (let ((overlay-i (car (overlays-at (posn-point (event-start event))))))
      ;; search for the string of current text line
      ;(pie-search (overlay-get overlay-i 'str-to-search))
      ;;(pie-search (concat "<H>" (replace-regexp-in-string "^ +" "" (overlay-get overlay-i 'str-to-search)) "</H>"))
      (pie-search (replace-regexp-in-string "^ +" "" (overlay-get overlay-i 'str-to-search)))
      )
    )
  )
;; (pie-search-overlay)


(defun pie-search (&optional muster-i buffer-c)
  "liest das Muster vom Minibuffer und ruft das XSLT/grep auf."

  (interactive)
    
    (if (not muster-i)
	;; Regexp lesen
	(setq muster-i (read-from-minibuffer
			(format "Muster für search.bat: ")))
      )
    ;; replace spaces at muster-i
    ; quotes are different beween text/plain and text/xml
    (setq muster-i (replace-regexp-in-string "^ +" "" (replace-regexp-in-string "[ \\n]+$" "" muster-i)))

    (if (> (length muster-i) 1)
	(progn
	  ;(cd (concat (getenv "MYBASE_DIR") "\\xml"))
	  ;(cd (getenv "MYBASE_DIR"))
	  (setq case-fold-search-old case-fold-search
		case-fold-search nil
		search-command
		(shell-command-to-string
;		 (concat "xsltproc.exe --stringparam pattern \""
;			 muster-i
;			 "\" xsl/ShellSearch.xsl ../config.xml"))
		 (concat "cd " (getenv "MYBASE_DIR") " & " "tmp\\search.bat" (if (string-match "[A-Z]" muster-i) "" " -i") " \"" muster-i "\""))
		)
	  (setq case-fold-search case-fold-search-old)
;	  (message search-command)
	  (grep search-command)
	  (switch-to-buffer "*grep*")
	  (delete-other-windows)
	  )
      (message "! No valid pattern ...")
      )
    )
;; (pie-search "proe")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie journal

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; pie 


(provide 'pie)
