<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:import href="Link.xsl"/>
  <xsl:import href="../Utils.xsl"/>
  <xsl:variable name="length_link" select="-1"/>
  <xsl:variable name="flag_fig" select="true()"/>
  <xsl:template match="pie">
    <xsl:if test="$flag_tree">
      <xsl:call-template name="TREE"/>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template name="TREE">
    <xsl:if test="count(//section[h]) &gt; 3">
      <hr/>
      <xsl:element name="pre">
        <xsl:for-each select="//section[h]">
          <xsl:for-each select="ancestor::section[h]">
            <xsl:text>   </xsl:text>
          </xsl:for-each>
          <xsl:element name="a">
            <xsl:attribute name="href">
              <xsl:value-of select="concat('#',generate-id(.))"/>
            </xsl:attribute>
            <xsl:value-of select="normalize-space(h)"/>
          </xsl:element>
          <xsl:value-of select="$newline"/>
        </xsl:for-each>
      </xsl:element>
      <hr/>
    </xsl:if>
  </xsl:template>
  <xsl:template match="author|date">
    <xsl:element name="center">
      <xsl:element name="i">
        <xsl:value-of select="."/>
      </xsl:element>
    </xsl:element>
  </xsl:template>
  <xsl:template match="h">
    <xsl:copy-of select="@class"/>
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="section">
    <xsl:if test="h">
      <xsl:element name="{concat('h',string(count(ancestor-or-self::section)))}">
        <xsl:element name="a">
          <xsl:attribute name="name">
            <xsl:value-of select="generate-id(.)"/>
          </xsl:attribute>
          <xsl:choose>
            <xsl:when test="h/@hidden &gt; 0">
              <xsl:element name="i">
                <xsl:apply-templates select="h"/>
              </xsl:element>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="h"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:element>
      </xsl:element>
    </xsl:if>
    <xsl:apply-templates select="*[not(name(.) = 'h')]"/>
  </xsl:template>
  <xsl:template match="target">
    <!-- valid target element -->
    <xsl:element name="p">
      <xsl:attribute name="class">
        <xsl:value-of select="name()"/>
      </xsl:attribute>
      <xsl:value-of select="."/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="task">
    <!-- valid task element -->
    <xsl:element name="p">
      <xsl:choose>
        <xsl:when test="@done">
          <xsl:attribute name="class">done</xsl:attribute>
        </xsl:when>
        <xsl:when test="@prio">
          <xsl:attribute name="class">p<xsl:value-of select="@prio"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          </xsl:otherwise>
      </xsl:choose>
      <!-- calendar marker -->
      <xsl:element name="u">
        <xsl:choose>
          <xsl:when test="@done">
            <xsl:value-of select="@done"/>
          </xsl:when>
          <xsl:when test="@date">
            <xsl:value-of select="@date"/>
          </xsl:when>
          <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
      </xsl:element>
      <xsl:text>: </xsl:text>
      <xsl:apply-templates select="h"/>
      <!--  -->
      <xsl:if test="@effort">
        <xsl:text> / </xsl:text>
        <xsl:value-of select="@effort"/>
      </xsl:if>
      <!--  -->
      <xsl:if test="contact">
        <xsl:element name="ul">
          <xsl:for-each select="contact">
            <xsl:element name="li">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$file_ref"/>
                  <xsl:text>#</xsl:text>
                  <xsl:value-of select="@idref"/>
                </xsl:attribute>
                <xsl:value-of select="@idref"/>
              </xsl:element>
              <xsl:apply-templates select="p|list|pre"/>
            </xsl:element>
          </xsl:for-each>
        </xsl:element>
      </xsl:if>
      <!--  -->
      <xsl:apply-templates select="p|list|pre"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="section[@class='slide']">
    <!-- slide section -->
    <xsl:element name="center">
      <xsl:element name="table">
        <xsl:attribute name="class">
          <xsl:value-of select="name(.)"/>
        </xsl:attribute>
        <xsl:attribute name="border">
          <xsl:text>0</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="cellspacing">
          <xsl:text>1</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="width">
          <xsl:text>80%</xsl:text>
        </xsl:attribute>
        <xsl:element name="tbody">
          <xsl:element name="tr">
            <xsl:element name="td">
              <xsl:attribute name="align">center</xsl:attribute>
              <xsl:element name="b">
                <xsl:element name="a">
                  <xsl:attribute name="name">
                    <xsl:value-of select="generate-id(.)"/>
                  </xsl:attribute>
                  <xsl:value-of select="h"/>
                </xsl:element>
              </xsl:element>
            </xsl:element>
          </xsl:element>
          <xsl:element name="tr">
            <xsl:element name="td">
              <xsl:attribute name="align">left</xsl:attribute>
              <xsl:apply-templates select="*[not(name(.) = 'h')]"/>
            </xsl:element>
          </xsl:element>
        </xsl:element>
      </xsl:element>
      <xsl:if test="$flag_slidecap">
        <xsl:element name="p">
          <xsl:element name="u">
            <xsl:text>Folie:</xsl:text>
          </xsl:element>
          <xsl:text> </xsl:text>
          <xsl:value-of select="h"/>
        </xsl:element>
      </xsl:if>
    </xsl:element>
  </xsl:template>
  <xsl:template match="vcard">
    <!-- vcard -->
    <xsl:element name="table">
      <xsl:attribute name="class">
        <xsl:value-of select="name(.)"/>
      </xsl:attribute>
      <xsl:attribute name="border">
        <xsl:text>0</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="width">
        <xsl:text>40%</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="cellspacing">
        <xsl:text>1</xsl:text>
      </xsl:attribute>
      <xsl:element name="tbody">
        <xsl:element name="tr">
          <xsl:element name="th">
            <xsl:choose>
              <xsl:when test="link">
                <xsl:element name="a">
                  <xsl:attribute name="href">
                    <xsl:value-of select="link"/>
                  </xsl:attribute>
                  <xsl:value-of select="concat(name,' ',firstname)"/>
                  <xsl:if test="title">
                    <xsl:value-of select="concat(', ',title)"/>
                  </xsl:if>
                </xsl:element>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="concat(name,' ',firstname)"/>
                <xsl:if test="title">
                  <xsl:value-of select="concat(', ',title)"/>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:element>
        </xsl:element>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:attribute name="align">
              <xsl:text>right</xsl:text>
            </xsl:attribute>
            <xsl:element name="a">
              <xsl:attribute name="href">
                <xsl:value-of select="concat('mailto:',mail/private)"/>
              </xsl:attribute>
              <xsl:value-of select="mail/private"/>
            </xsl:element>
            <xsl:element name="a">
              <xsl:attribute name="href">
                <xsl:value-of select="concat('mailto:',mail/work)"/>
              </xsl:attribute>
              <xsl:value-of select="mail/work"/>
            </xsl:element>
          </xsl:element>
        </xsl:element>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:value-of select="concat('Tel. ',phone/private)"/>
            <xsl:if test="phone/mobile">
              <xsl:value-of select="concat(', ',phone/mobile)"/>
            </xsl:if>
          </xsl:element>
        </xsl:element>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:value-of select="concat('Tel. ',phone/work)"/>
            <xsl:if test="phone/mobile">
              <xsl:value-of select="concat(', ',phone/mobile)"/>
            </xsl:if>
          </xsl:element>
        </xsl:element>
        <xsl:if test="p|list|img">
          <xsl:element name="tr">
            <xsl:element name="td">
            <xsl:apply-templates select="p|list|img"/>
            </xsl:element>
          </xsl:element>
        </xsl:if>
      </xsl:element>
    </xsl:element>
  </xsl:template>
  <xsl:template match="contact">
    <!-- list item -->
    <xsl:element name="table">
      <xsl:attribute name="class">
        <xsl:value-of select="name(.)"/>
      </xsl:attribute>
      <xsl:attribute name="border">
        <xsl:text>0</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="cellspacing">
        <xsl:text>1</xsl:text>
      </xsl:attribute>
      <xsl:element name="tbody">
        <xsl:element name="tr">
          <xsl:element name="th">
            <xsl:value-of select="name"/>
          </xsl:element>
        </xsl:element>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:apply-templates/>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:element>
  </xsl:template>
  <xsl:template match="list">
    <xsl:if test="child::*[not(@hidden) or @hidden &lt;= $level_hidden]">
      <xsl:choose>
        <xsl:when test="@enum = 'yes'">
          <!-- numerated list -->
          <xsl:element name="ol">
            <xsl:apply-templates/>
          </xsl:element>
        </xsl:when>
        <xsl:otherwise>
          <!-- para -->
          <xsl:element name="ul">
            <xsl:apply-templates/>
          </xsl:element>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  <xsl:template match="p">
    <xsl:choose>
      <xsl:when test="name(parent::node()) = 'list'">
        <!-- list item -->
        <xsl:choose>
          <xsl:when test="not(@hidden)">
            <!-- simple paragraph -->
            <xsl:element name="li">
              <xsl:apply-templates/>
            </xsl:element>
          </xsl:when>
          <xsl:when test="@hidden &lt;= $level_hidden">
            <!-- hidden paragraph -->
            <xsl:element name="li">
              <xsl:attribute name="class">hidden</xsl:attribute>
              <xsl:apply-templates/>
            </xsl:element>
          </xsl:when>
          <xsl:otherwise>
            <!-- really hidden paragraph -->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="not(@hidden)">
            <!-- simple paragraph -->
            <xsl:element name="p">
              <xsl:apply-templates/>
            </xsl:element>
          </xsl:when>
          <xsl:when test="@hidden &lt;= $level_hidden">
            <!-- hidden paragraph -->
            <xsl:element name="p">
              <xsl:attribute name="class">hidden</xsl:attribute>
              <xsl:apply-templates/>
            </xsl:element>
          </xsl:when>
          <xsl:otherwise>
            <!-- really hidden paragraph -->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="pre">
    <xsl:copy-of select="."/>
    <xsl:element name="br"/>
  </xsl:template>
  <xsl:template match="img">
    <xsl:copy-of select="."/>
  </xsl:template>
  <xsl:template match="table">
    <xsl:element name="center">
      <xsl:element name="table">
        <xsl:copy-of select="@*"/>
        <xsl:attribute name="width">90%</xsl:attribute>
        <xsl:copy-of select="*"/>
      </xsl:element>
    </xsl:element>
  </xsl:template>
  <xsl:template match="fig">
    <xsl:if test="$flag_fig and child::*">
      <xsl:choose>
        <xsl:when test="not(@hidden) or @hidden &lt;= $level_hidden">
          <!-- normal figure -->
          <xsl:element name="center">
            <xsl:apply-templates select="img"/>
            <xsl:if test="h">
              <xsl:element name="p">
                <xsl:element name="u">
                  <xsl:text>Abb.:</xsl:text>
                </xsl:element>
                <xsl:text> </xsl:text>
                <xsl:value-of select="h"/>
              </xsl:element>
            </xsl:if>
          </xsl:element>
        </xsl:when>
        <xsl:otherwise>
          <!--  -->
          <xsl:if test="h">
            <xsl:element name="p">
              <xsl:attribute name="class">hidden</xsl:attribute>
              <xsl:element name="u">
                <xsl:text>Abb.:</xsl:text>
              </xsl:element>
              <xsl:text> </xsl:text>
              <xsl:value-of select="h"/>
            </xsl:element>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  <xsl:template name="HEADER">
    <xsl:element name="head">
      <xsl:if test="not($file_css='')">
        <xsl:element name="link">
          <xsl:attribute name="rel">
            <xsl:text>stylesheet</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="media">
            <xsl:text>screen, print</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="type">
            <xsl:text>text/css</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="href">
            <xsl:value-of select="$file_css"/>
          </xsl:attribute>
        </xsl:element>
      </xsl:if>
      <xsl:element name="meta">
        <xsl:attribute name="name">
          <xsl:text>generator</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="content">
          <xsl:text>cxproc PIE/XML</xsl:text>
        </xsl:attribute>
      </xsl:element>
      <xsl:element name="meta">
        <xsl:attribute name="http-equiv">
          <xsl:text>cache-control</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="content">
          <xsl:text>no-cache</xsl:text>
        </xsl:attribute>
      </xsl:element>
      <xsl:element name="meta">
        <xsl:attribute name="http-equiv">
          <xsl:text>pragma</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="content">
          <xsl:text>no-cache</xsl:text>
        </xsl:attribute>
      </xsl:element>
      <xsl:if test="/pie/section/h">
        <xsl:element name="title">
          <xsl:value-of select="/pie/section/h"/>
        </xsl:element>
      </xsl:if>
    </xsl:element>
  </xsl:template>
  <xsl:template name="PIEFORM">
    <!-- output of all file related form elements in a table -->
    <xsl:element name="table">
      <xsl:attribute name="class">formicons</xsl:attribute>
      <xsl:element name="tbody">
        <xsl:element name="tr">
          <!-- Edit -->
            <xsl:call-template name="FORMICON">
              <xsl:with-param name="icon">
                <xsl:text>accessories-text-editor.png</xsl:text>
              </xsl:with-param>
              <xsl:with-param name="text">
                <xsl:text>Editor</xsl:text>
              </xsl:with-param>
              <xsl:with-param name="cxp">
                <xsl:choose>
                  <xsl:when test="$str_write='no'"/>
                  <xsl:when test="contains($file_plain,'.txt') or contains($file_plain,'cal') or contains($file_plain,'csv')">
                    <!-- TODO: use more accurate patterns --> 
                    <xsl:text>EditTxt</xsl:text>
                  </xsl:when>
                  <xsl:when test="contains($file_plain,'.mm')">
                    <xsl:text>EditMm</xsl:text>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:text>EditPie</xsl:text>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:with-param>
              <xsl:with-param name="file">
                <xsl:value-of select="$file_plain"/>
              </xsl:with-param>
            </xsl:call-template>
            <xsl:call-template name="SEPICONS"/>
          <!-- Source Text
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>text-x-generic.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Source Text</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>txtplain</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          -->
          <!-- Default Layout -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>text-html.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Default Layout</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>article</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Simplified Layout -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Simplified Layout</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:choose>
                <xsl:when test="contains($file_plain,'.mm')">
                  <xsl:text>mmhtmlsimple</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>articleSimple</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Simplified Indent Layout -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Simplified Indent Layout</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:choose>
                <xsl:when test="contains($file_plain,'.mm')">
                  <xsl:text>mmindent</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>articleIndent</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Compact Layout -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Compact Layout</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>mmhtmlshort</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Tag cloud -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Tag cloud</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>articleTags</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Plain Text -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>text-x-generic.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Plain Text</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>Text</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- MediaWiki Text -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>text-x-generic.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>MediaWiki Text</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>Mediawiki</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- PIE/XML -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>PIE/XML</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>Pie</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Mindmap -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Mindmap</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:choose>
                <xsl:when test="contains($file_plain,'.mm')">
                  <xsl:text>mmxmmap</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>Mindmap</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name="SEPICONS"/>
          <!-- PSP -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>PSP</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:choose>
                <xsl:when test="contains($file_plain,'.mm')">
                  <xsl:text>mmPSP</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>PSP</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!--
              <xsl:call-template name="FORMICON">
                <xsl:with-param name="icon">
                  <xsl:text>x-office-document.png</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="text">
                  <xsl:text>PIE/XML/Project</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="cxp">
                  <xsl:text>mmpieproject</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="file">
                  <xsl:value-of select="$file_plain"/>
                </xsl:with-param>
              </xsl:call-template>

              <xsl:call-template name="FORMICON">
                <xsl:with-param name="icon">
                  <xsl:text>x-office-document.png</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="text">
                  <xsl:text>MS Project Template</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="cxp">
                  <xsl:text>pieMSProject</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="file">
                  <xsl:value-of select="$file_plain"/>
                </xsl:with-param>
              </xsl:call-template>
              -->
          <!-- TODO -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>TODO</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>Todo</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Contacts -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Contacts</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>Contact</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Calendar -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-calendar.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Calendar</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>piecalendar</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
            <xsl:with-param name="anchor">
              <xsl:text>today</xsl:text>
            </xsl:with-param>
          </xsl:call-template>
          <!-- Presentation -->
          <xsl:call-template name="FORMICON">
            <xsl:with-param name="icon">
              <xsl:text>x-office-document.png</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="text">
              <xsl:text>Presentation</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="cxp">
              <xsl:text>PresentationIndex</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="file">
              <xsl:value-of select="$file_plain"/>
            </xsl:with-param>
          </xsl:call-template>
          <xsl:call-template name="SEPICONS"/>
          <!-- Direct link -->
          <xsl:element name="td">
            <xsl:attribute name="class">filename</xsl:attribute>
            <xsl:element name="a">
              <xsl:attribute name="href">
                <xsl:value-of select="concat('/',$file_plain)"/>
              </xsl:attribute>
              <xsl:attribute name="target">
                <xsl:text>mainframe</xsl:text>
              </xsl:attribute>
              <xsl:value-of select="$file_plain"/>
            </xsl:element>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:element>
  </xsl:template>
  <xsl:template name="FORMICON">
    <xsl:param name="icon">
      <xsl:text>text-x-generic.png</xsl:text>
    </xsl:param>
    <xsl:param name="text">
      <xsl:text>Generic</xsl:text>
    </xsl:param>
    <xsl:param name="cxp"/>
    <xsl:param name="anchor"/>
    <xsl:param name="file"/>
    <xsl:element name="td">
      <!-- form button -->
      <xsl:attribute name="class">formicon</xsl:attribute>
      <xsl:if test="not($cxp='')">
      <xsl:element name="form">
        <xsl:attribute name="method">
          <xsl:text>post</xsl:text>
        </xsl:attribute>
        <xsl:if test="not($anchor='')">
          <xsl:attribute name="action">
            <xsl:value-of select="concat('#',$anchor)"/>
          </xsl:attribute>
        </xsl:if>
        <xsl:element name="input">
          <xsl:attribute name="type">image</xsl:attribute>
          <xsl:attribute name="src">
            <xsl:value-of select="concat('/cxproc/icons/',$icon)"/>
          </xsl:attribute>
          <xsl:attribute name="alt">
            <xsl:value-of select="$text"/>
          </xsl:attribute>
          <xsl:attribute name="title">
            <xsl:value-of select="$text"/>
          </xsl:attribute>
        </xsl:element>
        <!-- hidden form input -->
        <xsl:element name="input">
          <xsl:attribute name="type">hidden</xsl:attribute>
          <xsl:attribute name="name">cxp</xsl:attribute>
          <xsl:attribute name="value">
            <xsl:value-of select="$cxp"/>
          </xsl:attribute>
        </xsl:element>
        <xsl:element name="input">
          <xsl:attribute name="type">hidden</xsl:attribute>
          <xsl:attribute name="name">write</xsl:attribute>
          <xsl:attribute name="value">
            <xsl:value-of select="$str_write"/>
          </xsl:attribute>
        </xsl:element>
        <xsl:element name="input">
          <xsl:attribute name="type">hidden</xsl:attribute>
          <xsl:attribute name="name">file</xsl:attribute>
          <xsl:attribute name="value">
            <xsl:value-of select="$file"/>
          </xsl:attribute>
        </xsl:element>
      </xsl:element>
      </xsl:if>
    </xsl:element>
  </xsl:template>
  <xsl:template name="SEPICONS">
    <xsl:element name="td">
      <xsl:attribute name="class">
        <xsl:text>separator</xsl:text>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>
</xsl:stylesheet>
