<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:import href="Link.xsl"/>
  <xsl:import href="../Utils.xsl"/>
  <xsl:variable name="length_link" select="-1"/>
  <xsl:variable name="flag_fig" select="true()"/>

  <xsl:template match="pie">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="h">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="section">
    <xsl:if test="h">
      <xsl:choose>
        <xsl:when test="count(ancestor::section) &lt; 4">
          <xsl:text>\</xsl:text>
          <xsl:for-each select="ancestor::section">
            <xsl:text>sub</xsl:text>
          </xsl:for-each>
          <xsl:text>section{</xsl:text>
          <xsl:apply-templates select="h"/>
          <xsl:text>}</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="h"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="$newline"/>
      <xsl:value-of select="$newline"/>
    </xsl:if>
    <xsl:apply-templates select="*[not(name(.) = 'h')]"/>
  </xsl:template>

  <xsl:template match="task">
    <!-- valid task element -->
    <xsl:element name="p">
      <xsl:choose>
        <xsl:when test="@done">
          <xsl:attribute name="class">done</xsl:attribute>
        </xsl:when>
        <xsl:when test="@prio">
          <xsl:attribute name="class">p<xsl:value-of select="@prio"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          </xsl:otherwise>
      </xsl:choose>
      <!-- calendar marker -->
      <xsl:element name="u">
        <xsl:choose>
          <xsl:when test="@done">
            <xsl:value-of select="@done"/>
          </xsl:when>
          <xsl:when test="@date">
            <xsl:value-of select="@date"/>
          </xsl:when>
          <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
      </xsl:element>
      <xsl:text>: </xsl:text>
      <xsl:apply-templates select="h"/>
      <!--  -->
      <xsl:if test="@effort">
        <xsl:text> / </xsl:text>
        <xsl:value-of select="@effort"/>
      </xsl:if>
      <!--  -->
      <xsl:if test="contact">
        <xsl:element name="ul">
          <xsl:for-each select="contact">
            <xsl:element name="li">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:value-of select="$file_ref"/>
                  <xsl:text>#</xsl:text>
                  <xsl:value-of select="@idref"/>
                </xsl:attribute>
                <xsl:value-of select="@idref"/>
              </xsl:element>
              <xsl:apply-templates select="p|list|pre"/>
            </xsl:element>
          </xsl:for-each>
        </xsl:element>
      </xsl:if>
      <!--  -->
      <xsl:apply-templates select="p|list|pre"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="contact">
    <!-- list item -->
    <xsl:element name="table">
      <xsl:attribute name="class">
        <xsl:value-of select="name(.)"/>
      </xsl:attribute>
      <xsl:attribute name="border">
        <xsl:text>0</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="cellspacing">
        <xsl:text>1</xsl:text>
      </xsl:attribute>
      <xsl:element name="tbody">
        <xsl:element name="tr">
          <xsl:element name="th">
            <xsl:value-of select="name"/>
          </xsl:element>
        </xsl:element>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:apply-templates/>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:element>
  </xsl:template>

  <xsl:template match="list">
    <xsl:if test="child::node()">
      <xsl:choose>
        <xsl:when test="@enum = 'yes'">
          <!-- numerated list -->
          <xsl:text>\begin{enumerate}</xsl:text>
          <xsl:value-of select="$newline"/>
          <xsl:apply-templates/>
          <xsl:text>\end{enumerate}</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <!-- para -->
          <xsl:text>\begin{itemize}</xsl:text>
          <xsl:value-of select="$newline"/>
          <xsl:apply-templates/>
          <xsl:text>\end{itemize}</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="$newline"/>
      <xsl:value-of select="$newline"/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="p">
    <xsl:choose>
      <xsl:when test="name(parent::node()) = 'list'">
        <!-- list item -->
        <xsl:text>\item </xsl:text>
        <xsl:apply-templates/>
        <xsl:value-of select="$newline"/>
      </xsl:when>
      <xsl:otherwise>
        <!-- para -->
        <xsl:apply-templates/>
        <xsl:value-of select="$newline"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$newline"/>
  </xsl:template>

  <xsl:template match="pre">
          <xsl:text>\begin{verbatim}</xsl:text>
          <xsl:value-of select="."/>
          <xsl:text>\end{verbatim}</xsl:text>
          <xsl:value-of select="$newline"/>
  </xsl:template>

  <xsl:template match="table">
    <xsl:element name="center">
      <xsl:element name="table">
        <xsl:copy-of select="@*"/>
        <xsl:attribute name="width">90%</xsl:attribute>
        <xsl:copy-of select="*"/>
      </xsl:element>
    </xsl:element>
  </xsl:template>

  <xsl:template match="fig">
    <xsl:if test="$flag_fig and child::*">
          <xsl:text>\begin{figure}</xsl:text>
          <xsl:value-of select="$newline"/>
          <xsl:apply-templates/>
        <xsl:if test="h">
          <xsl:text>\label{</xsl:text>
          <xsl:apply-templates select="h"/>
          <xsl:text>}</xsl:text>
        </xsl:if>
          <xsl:text>\end{figure}</xsl:text>
          <xsl:value-of select="$newline"/>
          <xsl:value-of select="$newline"/>
    </xsl:if>
  </xsl:template>

  <xsl:template name="HEADER">
    <xsl:element name="head">
      <xsl:element name="link">
        <xsl:attribute name="rel">
          <xsl:text>stylesheet</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="media">
          <xsl:text>screen, print</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="type">
          <xsl:text>text/css</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="href">
          <xsl:value-of select="$file_css"/>
        </xsl:attribute>
      </xsl:element>
      <xsl:if test="/pie/section/h">
        <xsl:element name="title">
          <xsl:value-of select="/pie/section/h"/>
        </xsl:element>
      </xsl:if>
    </xsl:element>
  </xsl:template>

  <xsl:template match="text()">
    <!-- simple text node -->
    <xsl:value-of select="normalize-space(.)"/>
  </xsl:template>

</xsl:stylesheet>
