<xsl:stylesheet version="1.0"
  		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--

PKG2 - ProzessKettenGenerator second implementation 
Copyright (C) 1999-2006 by Alexander Tenbusch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License 
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

-->

<xsl:output method="text" encoding="ISO-8859-1"/>  

<!-- use on validated and cleaned xml's only -->

<xsl:template match="PETRINET|SUBNET">
  <xsl:choose>
    <xsl:when test="not(attribute::ID)">
      <xsl:text>Net </xsl:text>
      <xsl:value-of select="position()"/>
      <xsl:text>: needs a name
</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:if test="not(child::NAME)">
        <xsl:text>Net </xsl:text>
        <xsl:value-of select="@ID"/>
        <xsl:text>: needs a name
</xsl:text>
      </xsl:if>
    </xsl:otherwise>
  </xsl:choose>
  <!-- empty net -->
  <xsl:if test="not(child::*)">
    <xsl:text>Net </xsl:text>
    <xsl:value-of select="@ID"/>
      <xsl:text>: is empty
</xsl:text>
  </xsl:if>

  <xsl:apply-templates select="SUBNET"/>
  <xsl:apply-templates select="STELLE"/>
  <xsl:apply-templates select="TRANSITION"/>
  <xsl:apply-templates select="REQUIREMENT"/>
  <xsl:apply-templates select="RELATION"/>
</xsl:template>

<xsl:template match="STELLE|TRANSITION|REQUIREMENT">
  <!-- these elements are needing ID and NAME -->
  <xsl:choose>
  <xsl:when test="not(attribute::ID)">
      <xsl:value-of select="name()"/>
      <xsl:text> </xsl:text>
    <xsl:value-of select="position()"/>
      <xsl:text>: needs a name
</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:variable name="id" select="@ID"/>
    <xsl:if test="not(child::NAME)">
      <xsl:value-of select="name()"/>
      <xsl:text> </xsl:text>
      <xsl:value-of select="@ID"/>
      <xsl:text>: needs a name
</xsl:text>
  </xsl:if>
  <!-- report undescribed elements -->
  <xsl:if test="not(child::DESCRIPTION)">
      <xsl:value-of select="name()"/>
      <xsl:text> </xsl:text>
      <xsl:value-of select="@ID"/>
      <xsl:text>: is not described
</xsl:text>
  </xsl:if>
  <!-- report isolated knots -->
  <xsl:if test="(self::STELLE and not(//RELATION[@FROM = $id or @TO = $id])) or (self::TRANSITION and not(//RELATION[@FROM = $id]))">
      <xsl:value-of select="name()"/>
      <xsl:text> </xsl:text>
      <xsl:value-of select="@ID"/>
      <xsl:text>: is isolated
</xsl:text>
  </xsl:if>

</xsl:otherwise>
</xsl:choose>
</xsl:template>


<xsl:template match="RELATION">
  <xsl:variable name="id_from" select="@FROM"/>
  <xsl:variable name="id_to"   select="@TO"/>

  <!-- knots must be STELLE/TRANSITION or TRANSITION/STELLE -->
  <xsl:if test="not((//STELLE[@ID = $id_from] and //TRANSITION[@ID = $id_to]) or (//TRANSITION[@ID = $id_from] and //STELLE[@ID = $id_to]))">
      <xsl:text>RELATION </xsl:text>
      <xsl:value-of select="@FROM"/>
      <xsl:text> -> </xsl:text>
      <xsl:value-of select="@TO"/>
      <xsl:text>: Knots not suitable
</xsl:text>
    </xsl:if>

  <xsl:if test="parent::SUBNET">
    <!-- both knots must be in same SUBNET -->
    <xsl:if test="not((../STELLE[@ID = $id_from] and ../TRANSITION[@ID = $id_to]) or (../TRANSITION[@ID = $id_from] and ../STELLE[@ID = $id_to]))">
      <xsl:text>RELATION </xsl:text>
      <xsl:value-of select="@FROM"/>
      <xsl:text> -> </xsl:text>
      <xsl:value-of select="@TO"/>
      <xsl:text>: Knots in different SUBNET's
</xsl:text>
    </xsl:if>
  </xsl:if>

  <xsl:if test="parent::PETRINET">
    <!-- both knots must be in same SUBNET -->
    <xsl:if test="//*[@ID = $id_from]/../@ID = //*[@ID = $id_to]/../@ID and not(//*[@ID = $id_from]/parent::PETRINET)">
      <xsl:text>RELATION </xsl:text>
      <xsl:value-of select="@FROM"/>
      <xsl:text> -> </xsl:text>
      <xsl:value-of select="@TO"/>
      <xsl:text>: Knots are in same SUBNET </xsl:text>
      <xsl:value-of select="//*[@ID = $id_from]/../@ID"/>
      <xsl:text>
</xsl:text>
    </xsl:if>
  </xsl:if>

</xsl:template>


</xsl:stylesheet>
